@@ -29,9 +29,7 @@
  
 #include "egg-datetime.h"
 
-#include "seahorse-action.h"
-#include "seahorse-icons.h"
-#include "seahorse-registry.h"
+#include "seahorse-common.h"
 #include "seahorse-passphrase.h"
 #include "seahorse-progress.h"
 #include "seahorse-util.h"
@@ -52,7 +50,7 @@
  **/
 
 void           on_gpgme_generate_response                    (GtkDialog *dialog,
-                                                              guint response,
+                                                              gint response,
                                                               gpointer user_data);
 
 void           on_gpgme_generate_entry_changed               (GtkEditable *editable,
@@ -113,7 +111,7 @@ seahorse_gpgme_generate_register (void)
 	gtk_action_group_add_actions (actions, ACTION_ENTRIES, G_N_ELEMENTS (ACTION_ENTRIES), NULL);
 	
 	/* Register this as a generator */
-	seahorse_registry_register_object (NULL, G_OBJECT (actions), SEAHORSE_PGP_TYPE_STR, "generator", NULL);
+	seahorse_registry_register_object (G_OBJECT (actions), "generator");
 }
 
 /* --------------------------------------------------------------------------
@@ -248,7 +246,7 @@ seahorse_gpgme_generate_key (SeahorseGpgmeKeyring *keyring,
  */
 G_MODULE_EXPORT void
 on_gpgme_generate_response (GtkDialog *dialog,
-                            guint response,
+                            gint response,
                             gpointer user_data)
 {
     SeahorseWidget *swidget = SEAHORSE_WIDGET (user_data);
@@ -296,7 +294,7 @@ on_gpgme_generate_response (GtkDialog *dialog,
     widget = seahorse_widget_get_widget (swidget, "algorithm-choice");
     g_return_if_fail (widget != NULL);
     sel = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
-    g_assert (sel <= G_N_ELEMENTS(available_algorithms));
+    g_assert (sel <= (gint) G_N_ELEMENTS(available_algorithms));
     type = available_algorithms[sel].type;
 
     /* The number of bits */
